@@ -27,7 +27,7 @@ public class CellRendererPixbuf extends CellRenderer {
     /**
      * Attributes for the CellRenderer
      */
-    public static class Attribute extends CellRendererAttribute {
+    public static class Attribute extends CellRenderer.Attribute {
         private Attribute(String attr) {
             super(attr);
         }
