@@ -9,26 +9,24 @@
 
 package org.gnu.gtk;
 
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
+import org.gnu.glib.Handle;
 
 /**
  * The Separator class is the base class for {@link HSeparator} and
  * {@link VSeparator}.
  */
-public abstract class Separator extends Widget 
-{
-	protected Separator(Handle handle) {
-	    super(handle);
-	}
-	
-	/**
-	 * Retrieve the runtime type used by the GLib library.
-	 */
-	public static Type getType() {
-		return new Type(gtk_separator_get_type());
-	}
+public abstract class Separator extends Widget {
+    protected Separator(Handle handle) {
+        super(handle);
+    }
 
-    native static final protected int gtk_separator_get_type ();
+    /**
+     * Retrieve the runtime type used by the GLib library.
+     */
+    public static Type getType() {
+        return new Type(gtk_separator_get_type());
+    }
+
+    native static final protected int gtk_separator_get_type();
 }
-
