@@ -13,16 +13,15 @@ import org.gnu.glib.Handle;
 import org.gnu.glib.MemStruct;
 
 /**
- * Attributed text is used in a number of places in Pango. It is used
- * as the input to the itemization process and also when creating a
- * {@link Layout}. The data types and functions in this section are
- * used to represent and manipulate sets of attributes applied to a
- * portion of text.
+ * Attributed text is used in a number of places in Pango. It is used as the
+ * input to the itemization process and also when creating a {@link Layout}.
+ * The data types and functions in this section are used to represent and
+ * manipulate sets of attributes applied to a portion of text.
  */
-public class Attribute extends MemStruct
-{
-    protected Attribute() {}
-    
+public class Attribute extends MemStruct {
+    protected Attribute() {
+    }
+
     protected Attribute(Handle handle) {
         super(handle);
     }
@@ -30,7 +29,7 @@ public class Attribute extends MemStruct
     /**
      * Returns the start index of the range
      */
-    public int getStartIndex(){
+    public int getStartIndex() {
         return getStartIndex(getHandle());
     }
 
@@ -38,11 +37,11 @@ public class Attribute extends MemStruct
      * Returns end index of the range. The character at this index is not
      * included in the range.
      */
-    public int getEndIndex(){
+    public int getEndIndex() {
         return getEndIndex(getHandle());
     }
 
-    native static final protected int getStartIndex (Handle obj);
-    native static final protected int getEndIndex (Handle obj);
-}
+    native static final protected int getStartIndex(Handle obj);
 
+    native static final protected int getEndIndex(Handle obj);
+}
