@@ -9,7 +9,7 @@
 
 package org.gnu.pango;
 
-import org.gnu.javagnome.Enum;
+import org.gnu.glib.Enum;
 
 /**
  * A PangoTabAlign specifies where a tab stop appears relative to the text
